@@ -1,5 +1,5 @@
 #include <sys/param.h>
-#include <kapp.h>
+#include <kapplication.h>
 #include <qdir.h>
 #include <qpixmap.h>
 #include <qimage.h>
@@ -11,14 +11,14 @@
 #include "Preview.moc"
 #include "Preferences.h"
 #include "kmessagebox.h"
-#include "kstddirs.h"
+#include "kstandarddirs.h"
 #include "kglobal.h"
 #include "klocale.h"
 #include <qfileinfo.h>
 
-#include <qpushbt.h>
+#include <qpushbutton.h>
 #include <qcombobox.h>
-#include <qbttngrp.h>
+#include <qbuttongroup.h>
 
 static const char * themeMagicV1_0= "kmahjongg-theme-v1.0";
 
@@ -39,8 +39,10 @@ Preview::Preview
 	bottomGroup->setMaximumSize( 32767, 32767 );
 	bottomGroup->setFocusPolicy( QWidget::NoFocus );
 	bottomGroup->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300
 	bottomGroup->setFontPropagation( QWidget::NoChildren );
 	bottomGroup->setPalettePropagation( QWidget::NoChildren );
+#endif
 	bottomGroup->setFrameStyle( 49 );
 	bottomGroup->setTitle( "" );
 	bottomGroup->setAlignment( 1 );
@@ -51,8 +53,10 @@ Preview::Preview
 	topGroup->setMaximumSize( 32767, 32767 );
 	topGroup->setFocusPolicy( QWidget::NoFocus );
 	topGroup->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300
 	topGroup->setFontPropagation( QWidget::NoChildren );
 	topGroup->setPalettePropagation( QWidget::NoChildren );
+#endif
 	topGroup->setFrameStyle( 49 );
 	topGroup->setTitle( "" );
 	topGroup->setAlignment( 1 );
@@ -63,10 +67,11 @@ Preview::Preview
 	combo->setMaximumSize( 32767, 32767 );
 	combo->setFocusPolicy( QWidget::StrongFocus );
 	combo->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	combo->setFontPropagation( QWidget::AllChildren );
 	combo->setPalettePropagation( QWidget::AllChildren );
+#endif
 	combo->setSizeLimit( 10 );
-	combo->setAutoResize( FALSE );
 	connect( combo, SIGNAL(activated(int)), SLOT(selectionChanged(int)) );
 
 	loadButton = new QPushButton( this, "loadButton" );
@@ -76,11 +81,12 @@ Preview::Preview
 	connect( loadButton, SIGNAL(clicked()), SLOT(load()) );
 	loadButton->setFocusPolicy( QWidget::TabFocus );
 	loadButton->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	loadButton->setFontPropagation( QWidget::NoChildren );
 	loadButton->setPalettePropagation( QWidget::NoChildren );
+#endif
 	loadButton->setText(i18n("Load"));
 	loadButton->setAutoRepeat( FALSE );
-	loadButton->setAutoResize( FALSE );
 
 	//       total w  - button tot wid /4 (space left)
 	int bw = ((310+dx) - ((90+(dx/3))*3))/4 ;
@@ -93,11 +99,12 @@ Preview::Preview
 	connect( okButton, SIGNAL(clicked()), SLOT(ok()) );
 	okButton->setFocusPolicy( QWidget::TabFocus );
 	okButton->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	okButton->setFontPropagation( QWidget::NoChildren );
 	okButton->setPalettePropagation( QWidget::NoChildren );
+#endif
 	okButton->setText( i18n("&OK") );
 	okButton->setAutoRepeat( FALSE );
-        okButton->setAutoResize( FALSE );
         okButton->setDefault(true);
 
 	pos += (90+(dx/3))+bw;
@@ -108,11 +115,12 @@ Preview::Preview
 	connect( applyButton, SIGNAL(clicked()), SLOT(apply()) );
 	applyButton->setFocusPolicy( QWidget::TabFocus );
 	applyButton->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	applyButton->setFontPropagation( QWidget::NoChildren );
 	applyButton->setPalettePropagation( QWidget::NoChildren );
+#endif
 	applyButton->setText( i18n("Apply") );
 	applyButton->setAutoRepeat( FALSE );
-	applyButton->setAutoResize( FALSE );
 
 	pos += (90+(dx/3))+bw;
 	cancelButton = new QPushButton( this, "cancelButton" );
@@ -122,11 +130,12 @@ Preview::Preview
 	connect( cancelButton, SIGNAL(clicked()), SLOT(reject()) );
 	cancelButton->setFocusPolicy( QWidget::TabFocus );
 	cancelButton->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	cancelButton->setFontPropagation( QWidget::NoChildren );
 	cancelButton->setPalettePropagation( QWidget::NoChildren );
+#endif
 	cancelButton->setText( i18n("&Cancel") );
 	cancelButton->setAutoRepeat( FALSE );
-	cancelButton->setAutoResize( FALSE );
 
 	drawFrame = new FrameImage( this, "drawFrame" );
 	drawFrame->setGeometry( 10, 60, 310+dx, 170+dy );
@@ -134,8 +143,10 @@ Preview::Preview
 	drawFrame->setMaximumSize( 32767, 32767 );
 	drawFrame->setFocusPolicy( QWidget::NoFocus );
 	drawFrame->setBackgroundMode( QWidget::PaletteBackground );
+#if QT_VERSION < 300  
 	drawFrame->setFontPropagation( QWidget::NoChildren );
 	drawFrame->setPalettePropagation( QWidget::NoChildren );
+#endif
 	drawFrame->setFrameStyle( 49 );
 
 
@@ -187,25 +198,25 @@ void Preview::initialise(const PreviewType type, const char *extension)
 	// value initially. Set the caption to indicate what we are doing
 	switch (type) {
 	    case background:
-		      setCaption(kapp->makeStdCaption(i18n("Change background image")));
+		      setCaption(kapp->makeStdCaption(i18n("Change Background Image")));
 		      selectedFile = preferences.background();
 		      fileSelector = i18n("*.bgnd|Background Image\n"
 				     "*.bmp|Windows bitmap file (*.bmp)\n");
 		  break;
             case tileset:
-		      setCaption(kapp->makeStdCaption(i18n("Change tile set")));
+		      setCaption(kapp->makeStdCaption(i18n("Change Tile Set")));
 		      fileSelector = i18n("*.tileset|Tile set file\n");
 		      selectedFile = preferences.tileset();
 		  break;
             case board:
 		      fileSelector = i18n("*.layout|Board layout file\n");
-		      setCaption(kapp->makeStdCaption(i18n("Change board layout")));
+		      setCaption(kapp->makeStdCaption(i18n("Change Board Layout")));
 		      selectedFile = preferences.layout();
 	          break;
 
 	    case theme:
 		     fileSelector = i18n("*.theme|Kmahjongg theme\n");
-		     setCaption(kapp->makeStdCaption(i18n("Choose a theme")));
+		     setCaption(kapp->makeStdCaption(i18n("Choose a Theme")));
 		     selectedFile="";
 
 		     themeLayout="";
@@ -547,7 +558,7 @@ void Preview::saveTheme(void) {
         NULL,
         "*.theme",
         parentWidget(),
-        i18n("Save theme." ));
+        i18n("Save Theme" ));
     if ( url.isEmpty() )
         return;
 
