@@ -1,53 +1,43 @@
 #include "field.h"
+#include "field.moc"
 
 #include <math.h>
 
-#include <qlayout.h>
 #include <qbitmap.h>
-#include <qapplication.h>
+#include <qlayout.h>
+#include <qstyle.h>
+#include <qtimer.h>
 
 #include <klocale.h>
 
-Field::Field(QWidget *parent, const char *name)
-: QFrame(parent, name), lev(LEVELS[0]), random(0), state(Stopped),
-  u_mark(false), cursor(false)
+
+//-----------------------------------------------------------------------------
+Field::Field(QWidget *parent)
+: QFrame(parent, "field"),
+  _level(Level::Easy), state(Stopped), u_mark(false), cursor(false), button(0)
 {
 	setFrameStyle( QFrame::Box | QFrame::Raised );
 	setLineWidth(2);
 	setMidLineWidth(2);
 
-	QVBoxLayout *top = new QVBoxLayout(this, 0);
-	top->addStretch(1);
-	pb = new QPushButton(i18n("Press to resume"), this);
-	pb->hide();
-	top->addWidget(pb, 0, AlignCenter);
-	connect(pb, SIGNAL(clicked()), this, SLOT(resume()));
-	top->addStretch(1);
-
-	dummy = new QPushButton(0);
-	
 	readSettings();
 }
 
-Field::~Field()
-{
-	delete dummy;
-}
-
 void Field::readSettings()
 {
-	setCaseProperties(OptionDialog::readCaseProperties());
-	setUMark(OptionDialog::readUMark());
-	setCursor(OptionDialog::readKeyboard());
+	setCaseProperties( AppearanceSettings::readCaseProperties() );
+	setUMark( GameSettings::readUMark() );
+	setCursor( GameSettings::readKeyboard() );
 	for (uint i=0; i<3; i++)
-		mb[i] = OptionDialog::readMouseBinding((MouseButton)i);
+		mb[i] = GameSettings::readMouseBinding((MouseButton)i);
 }
 
 void Field::setCaseProperties(const CaseProperties &_cp)
 {
 	cp = _cp;
-	dummy->resize(cp.size, cp.size);
-	
+	button.resize(cp.size, cp.size);
+	updateGeometry();
+
 	QBitmap mask;
 
 	flagPixmap(mask, true);
@@ -70,8 +60,6 @@ void Field::setCaseProperties(const CaseProperties &_cp)
 	f.setPointSize(cp.size-6);
 	f.setBold(true);
 	setFont(f);
-
-	updateGeometry();
 }
 
 void Field::flagPixmap(QPixmap &pix, bool mask) const
@@ -85,8 +73,8 @@ void Field::flagPixmap(QPixmap &pix, bool mask) const
 	p.drawLine(8, 12, 12, 12);
 	p.drawLine(9, 11, 11, 11);
 	p.drawLine(10, 2, 10, 10);
-	if (!mask) p.setPen(cp.flagColor);
-	p.setBrush( (mask ? color1 : cp.flagColor) );
+	if (!mask) p.setPen(cp.colors[FlagColor]);
+	p.setBrush( (mask ? color1 : cp.colors[FlagColor]) );
 	p.drawRect(4, 3, 6, 5);
 }
 
@@ -98,7 +86,7 @@ void Field::minePixmap(QPixmap &pix, bool mask, CaseState type) const
 	p.setWindow(0, 0, 20, 20);
 
 	if ( type==Exploded )
-		p.fillRect(2, 2, 16, 16, (mask ? color1 : cp.explosionColor));
+		p.fillRect(2, 2, 16, 16, (mask ? color1 : cp.colors[ExplosionColor]));
 
 	QPen pen(mask ? color1 : black, 1);
 	p.setPen(pen);
@@ -108,12 +96,12 @@ void Field::minePixmap(QPixmap &pix, bool mask, CaseState type) const
 	p.drawLine(5, 5, 16, 16);
 	p.drawLine(5, 15, 15, 5);
 	p.drawEllipse(5, 5, 11, 11);
-	
+
 	p.fillRect(8, 8, 2, 2, (mask ? color1 : white));
 
 	if ( type==Marked ) {
 		if (!mask) {
-			pen.setColor(cp.errorColor);
+			pen.setColor(cp.colors[ErrorColor]);
 			p.setPen(pen);
 		}
 		p.drawLine(3, 3, 17, 17);
@@ -127,8 +115,8 @@ void Field::minePixmap(QPixmap &pix, bool mask, CaseState type) const
 
 QSize Field::sizeHint() const
 {
-	return QSize(2*frameWidth() + lev.width*cp.size,
-				 2*frameWidth() + lev.height*cp.size);
+	return QSize(2*frameWidth() + _level.width()*cp.size,
+				 2*frameWidth() + _level.height()*cp.size);
 }
 
 QSizePolicy Field::sizePolicy() const
@@ -136,20 +124,20 @@ QSizePolicy Field::sizePolicy() const
 	return QSizePolicy(QSizePolicy::Fixed, QSizePolicy::Fixed);
 }
 
-const Case &Field::pfield(uint i, uint j) const
+const KMines::Case &Field::pfield(uint i, uint j) const
 {
-	return _pfield[i + j*(lev.width+2)];
+	return _pfield[i + j*(_level.width()+2)];
 }
 
-Case &Field::pfield(uint i, uint j)
+KMines::Case &Field::pfield(uint i, uint j)
 {
-	return _pfield[i + j*(lev.width+2)];
+	return _pfield[i + j*(_level.width()+2)];
 }
 
 uint Field::computeNeighbours(uint i, uint j) const
 {
 	uint nm = 0;
-	
+
 	if (pfield(i-1,   j).mine) nm++;
 	if (pfield(i-1, j+1).mine) nm++;
 	if (pfield(i-1, j-1).mine) nm++;
@@ -158,61 +146,62 @@ uint Field::computeNeighbours(uint i, uint j) const
 	if (pfield(i+1,   j).mine) nm++;
 	if (pfield(i+1, j+1).mine) nm++;
 	if (pfield(i+1, j-1).mine) nm++;
-	
+
 	return nm;
 }
 
-void Field::setLevel(const Level &l)
+void Field::setLevel(const Level &level)
 {
-	lev = l;
-	restart(false);
+	_level = level;
+	restart();
 	updateGeometry();
 }
 
-void Field::restart(bool repaint)
+void Field::restart()
 {
-	/* if game is paused : resume before restart */
-	if ( state==Paused ) {
-		resume();
-		emit freezeTimer();
+	state = Playing;
+	firstReveal = true;
+	currentAction = None;
+	ic = _level.width()/2;
+	jc = _level.height()/2;
+
+	Case tmp;
+	tmp.mine = false;
+	tmp.state = Covered;
+	_pfield.fill(tmp, (_level.width()+2) * (_level.height()+2) );
+
+	// fill hidden borders
+	tmp.state = Uncovered;
+	for (uint i=0; i<_level.width()+2; i++) {
+		pfield(i, 0) = tmp;
+		pfield(i, _level.height()+1) = tmp;
+	}
+	for (uint j=0; j<_level.height()+2; j++) {
+		pfield(0, j) = tmp;
+		pfield(_level.width()+1, j) = tmp;
 	}
 
-	state = Playing;
-	first_click = true;
-	currentAction = None;
-	ic = lev.width/2;
-	jc = lev.height/2;
-
-	_pfield.resize( (lev.width+2) * (lev.height+2) );
-	
-	
-	for (uint i=0; i<lev.width+2; i++)
-		for (uint j=0; j<lev.height+2; j++) {
-			Case tmp;
-			tmp.mine  = false;
-			tmp.state = (i==0 || i==lev.width+1 || j==0 || j==lev.height+1
-						 ? Uncovered : Covered);
-			if ( pfield(i, j).mine==false && pfield(i, j).state==tmp.state )
-				continue;
-			pfield(i, j) = tmp;
-			if (repaint && tmp.state==Covered) drawCase(i, j);
-		}
+	update();
 }
 
 void Field::paintEvent(QPaintEvent *e)
 {
 	QPainter p(this);
 	drawFrame(&p);
-	p.end();
 
 	if ( state==Paused ) return;
 
-	uint imin = (uint)QMAX(QMIN(xToI(e->rect().left()), (int)lev.width), 1);
-	uint imax = (uint)QMAX(QMIN(xToI(e->rect().right()), (int)lev.width), 1);
-	uint jmin = (uint)QMAX(QMIN(yToJ(e->rect().top()), (int)lev.height), 1);
-	uint jmax = (uint)QMAX(QMIN(yToJ(e->rect().bottom()), (int)lev.height), 1);
+	uint imin
+        = (uint)QMAX(QMIN(xToI(e->rect().left()), (int)_level.width()), 1);
+	uint imax
+        = (uint)QMAX(QMIN(xToI(e->rect().right()), (int)_level.width()), 1);
+	uint jmin
+        = (uint)QMAX(QMIN(yToJ(e->rect().top()), (int)_level.height()), 1);
+	uint jmax
+        = (uint)QMAX(QMIN(yToJ(e->rect().bottom()), (int)_level.height()), 1);
 	for (uint i=imin; i<=imax; i++)
-	    for (uint j=jmin; j<=jmax; j++) drawCase(i, j);
+	    for (uint j=jmin; j<=jmax; j++)
+            drawCase(p, i, j);
 }
 
 void Field::changeCaseState(uint i, uint j, CaseState new_st)
@@ -220,7 +209,8 @@ void Field::changeCaseState(uint i, uint j, CaseState new_st)
 	emit changeCase(pfield(i, j).state, -1);
 	pfield(i, j).state = new_st;
 	emit changeCase(new_st, 1);
-	drawCase(i, j);
+    QPainter p(this);
+	drawCase(p, i, j);
 	if ( state==Playing ) emit updateStatus(pfield(i, j).mine);
 }
 
@@ -266,15 +256,16 @@ void Field::uncover(uint i, uint j)
 
 bool Field::inside(int i, int j) const
 {
-	return ( i>=1 && i<=(int)lev.width && j>=1 && j<=(int)lev.height);
+	return ( i>=1 && i<=(int)_level.width() && j>=1
+             && j<=(int)_level.height());
 }
 
-MouseAction Field::mapMouseButton(QMouseEvent *e) const
+KMines::MouseAction Field::mapMouseButton(QMouseEvent *e) const
 {
 	switch (e->button()) {
-	case LeftButton:  return mb[Left];
-	case MidButton:   return mb[Mid];
-	case RightButton: return mb[Right];
+	case LeftButton:  return mb[KMines::Left];
+	case MidButton:   return mb[KMines::Mid];
+	case RightButton: return mb[KMines::Right];
 	default:          return Mark;
 	}
 }
@@ -353,8 +344,8 @@ void Field::mouseMoveEvent(QMouseEvent *e)
 
 void Field::showMines()
 {
-	for(uint i=1; i<=lev.width; i++)
-		for(uint j=1; j<=lev.height; j++) {
+	for(uint i=1; i<=_level.width(); i++)
+		for(uint j=1; j<=_level.height(); j++) {
 		    if ( !pfield(i, j).mine ) continue;
 			if ( pfield(i, j).state!=Exploded && pfield(i, j).state!=Marked )
 				changeCaseState(i, j, Uncovered);
@@ -363,7 +354,10 @@ void Field::showMines()
 
 void Field::pressCase(uint i, uint j, bool pressed)
 {
-	if ( pfield(i, j).state==Covered ) drawBox(i, j, pressed);
+	if ( pfield(i, j).state==Covered ) {
+        QPainter p(this);
+        drawBox(p, i, j, pressed);
+    }
 }
 
 void Field::pressClearFunction(uint i, uint j, bool pressed)
@@ -379,44 +373,36 @@ void Field::pressClearFunction(uint i, uint j, bool pressed)
 	pressCase(i+1, j+1, pressed);
 }
 
-#define M_OR_U(i, j) ( pfield(i, j).state==Marked \
-					   || pfield(i, j).state==Uncertain )
-
 void Field::keyboardAutoReveal()
 {
-	pressClearFunction(ic, jc, false);
+	pressClearFunction(ic, jc, true);
 	QTimer::singleShot(50, this, SLOT(keyboardAutoRevealSlot()));
 }
 
 void Field::keyboardAutoRevealSlot()
 {
-	pressClearFunction(ic, jc, true);
+	pressClearFunction(ic, jc, false);
 	autoReveal();
 }
 
 void Field::autoReveal()
 {
 	if ( state!=Playing ) return;
-	switch (pfield(ic, jc).state) {
-	case Covered:
-	case Marked:
-	case Uncertain: return;
-	default:        break;
-	}
-	
-	/* number of mines around the case */
+    if ( pfield(ic, jc).state!=Uncovered ) return;
+    emit incActions();
+
+	// number of mines around the case
 	uint nm = computeNeighbours(ic, jc);
-	if M_OR_U(ic-1,   jc) nm--;
-	if M_OR_U(ic-1, jc+1) nm--;
-	if M_OR_U(ic-1, jc-1) nm--;
-	if M_OR_U(  ic, jc+1) nm--;
-	if M_OR_U(  ic, jc-1) nm--;
-	if M_OR_U(ic+1,   jc) nm--;
-	if M_OR_U(ic+1, jc+1) nm--;
-	if M_OR_U(ic+1, jc-1) nm--;
-	
-	if (!nm) { /* the number of surrounding mines is equal */
-		       /* to the number of marks :) */
+	if ( pfield(ic-1,   jc).state==Marked ) nm--;
+	if ( pfield(ic-1, jc+1).state==Marked ) nm--;
+	if ( pfield(ic-1, jc-1).state==Marked ) nm--;
+	if ( pfield(  ic, jc+1).state==Marked ) nm--;
+	if ( pfield(  ic, jc-1).state==Marked ) nm--;
+	if ( pfield(ic+1,   jc).state==Marked ) nm--;
+	if ( pfield(ic+1, jc+1).state==Marked ) nm--;
+	if ( pfield(ic+1, jc-1).state==Marked ) nm--;
+
+	if (!nm) { // number of surrounding mines == number of marks :)
 		uncoverCase(ic+1, jc+1);
 		uncoverCase(ic+1,   jc);
 		uncoverCase(ic+1, jc-1);
@@ -427,46 +413,39 @@ void Field::autoReveal()
 		uncoverCase(ic-1, jc-1);
 	}
 }
-	
+
 void Field::uncoverCase(uint i, uint j)
 {
-	if ( pfield(i, j).state==Covered ) {
-		if ( pfield(i, j).mine ) changeCaseState(i, j, Uncovered);
-		else uncover(i, j);
-	}
+	if ( pfield(i, j).state!=Covered ) return;
 
-	/* to enable multiple explosions ... */
-	if ( pfield(i, j).mine && pfield(i, j).state==Uncovered ) {
-		changeCaseState(i, j, Exploded);
-		_endGame();
-	}
-}
+    if ( !pfield(i, j).mine ) {
+        uncover(i, j);
+        return;
+    }
 
-void Field::_endGame()
-{
-	if ( state==Stopped ) return;
-	/* find all errors */
-	for (uint ii=1; ii<lev.width+1; ii++)
-		for (uint jj=1; jj<lev.height+1; jj++)
-			if ( pfield(ii, jj).state==Marked && !pfield(ii, jj).mine )
-				changeCaseState(ii, jj, Error);
-	emit endGame();
+    // explosion
+    changeCaseState(i, j, Exploded);
+    // if this is not the first explosion, the game is already stopped
+    if ( state==Stopped ) return;
+
+    // find all errors
+    for (uint ii=1; ii<_level.width()+1; ii++)
+        for (uint jj=1; jj<_level.height()+1; jj++)
+            if ( pfield(ii, jj).state==Marked && !pfield(ii, jj).mine )
+                changeCaseState(ii, jj, Error);
+
+    emit gameLost();
 }
 
 void Field::pause()
 {
-	if ( first_click || state==Stopped ) return;
-	
-	/* if already in pause : resume game */
-	if ( state==Paused ) resume();
+	if ( firstReveal || state==Stopped ) return;
+
+	if ( state==Paused ) resume(); // if already paused : resume game
 	else {
-		emit freezeTimer();
-		QFont f = QApplication::font();
-		f.setBold(true);
-		pb->setFont(f);
-		pb->show();
-		pb->setFocus();
+		emit stopTimer();
 		state = Paused;
+        emit setMood(Smiley::Sleeping);
 		emit gameStateChanged(Paused);
 		update();
 	}
@@ -475,8 +454,8 @@ void Field::pause()
 void Field::resume()
 {
 	state = Playing;
+    emit setMood(Smiley::Normal);
 	emit gameStateChanged(Playing);
-	pb->hide();
 	emit startTimer();
 	update();
 }
@@ -504,34 +483,36 @@ void Field::right()
 void Field::reveal()
 {
 	if ( state!=Playing ) return;
-	if ( first_click ) {
+    emit incActions();
+	if (firstReveal) {
 		// set mines positions on field ; must avoid the first
 		// clicked case
-		for(uint k=0; k<lev.nbMines; k++) {
+		for(uint k=0; k<_level.nbMines(); k++) {
 			uint i, j;
 			do {
-				i = random.getLong(lev.width);
-				j = random.getLong(lev.height);
+				i = _random.getLong(_level.width());
+				j = _random.getLong(_level.height());
 			} while ( pfield(i+1, j+1).mine
 					  || ((i+1)==(uint)ic && (j+1)==(uint)jc) );
-			
+
 			pfield(i+1, j+1).mine = true;
 		}
 		emit startTimer();
-		first_click = false;
+		firstReveal = false;
 		emit gameStateChanged(Playing);
 	}
-	
+
 	uncoverCase(ic, jc);
 }
 
 void Field::mark()
 {
 	if ( state!=Playing ) return;
+    emit incActions();
 	switch (pfield(ic, jc).state) {
 	case Covered:   changeCaseState(ic, jc, Marked); break;
 	case Marked:    changeCaseState(ic, jc, (u_mark ? Uncertain : Covered));
-		            break;
+		        break;
 	case Uncertain:	changeCaseState(ic, jc, Covered); break;
 	default:        break;
 	}
@@ -540,6 +521,7 @@ void Field::mark()
 void Field::umark()
 {
 	if ( state!=Playing ) return;
+    emit incActions();
 	switch (pfield(ic, jc).state) {
 	case Covered:
 	case Marked:    changeCaseState(ic, jc, Uncertain); break;
@@ -556,8 +538,9 @@ bool Field::placeCursor(int i, int j)
 	ic = (uint)i;
 	jc = (uint)j;
 	if (cursor) {
-		drawCase(oldIc, oldJc);
-		drawCase(ic, jc);
+        QPainter p(this);
+		drawCase(p, oldIc, oldJc);
+		drawCase(p, ic, jc);
 	}
 	return true;
 }
@@ -565,57 +548,68 @@ bool Field::placeCursor(int i, int j)
 void Field::setCursor(bool show)
 {
 	cursor = show;
-	if ( state==Playing ) drawCase(ic, jc);
+	if ( state==Playing ) {
+        QPainter p(this);
+        drawCase(p, ic, jc);
+    }
 }
 
 // draw methods
-void Field::drawBox(uint i, uint j, bool pressed,
-					const QString &text, const QColor *textColor,
-					const QPixmap *pixmap)
+void Field::drawBox(QPainter &p, uint i, uint j, bool pressed,
+                    const QPixmap *pixmap, const QString &text,
+                    const QColor &textColor)
 {
-	QPainter p(this);
 	int x = iToX(i);
 	int y = jToY(j);
 
-	// draw button
 	p.translate(x, y);
-	dummy->setDown(pressed);
-	style().drawPushButton(dummy, &p);
+
+	QStyle::SFlags flags = QStyle::Style_Enabled;
+	if (pressed) flags |= QStyle::Style_Down;
+	else flags |= QStyle::Style_Raised;
+	if ( cursor && i==ic && j==jc ) flags |= QStyle::Style_HasFocus;
+
+	style().drawControl(QStyle::CE_PushButton, &p, &button, button.rect(),
+                        colorGroup(), flags);
+	style().drawControl(QStyle::CE_PushButtonLabel, &p, &button,
+                      style().subRect(QStyle::SR_PushButtonFocusRect, &button),
+                        colorGroup(), flags);
+
+	// we need to draw directly because the pushbutton control clips too much
+	// text and pixmap ...
 	p.resetXForm();
-
-	// draw text and pixmap
-	style().drawItem(&p, x, y, cp.size, cp.size, AlignCenter, colorGroup(),
-					 true, pixmap, text, -1, textColor);
-	
-	// draw cursor
-	if ( cursor && i==ic && j==jc ) {
-		QRect r = style().buttonRect(x+1, y+1, cp.size-2, cp.size-2);
-		style().drawFocusRect(&p, r, colorGroup());
-	}
+	QRect r(x, y, cp.size, cp.size);
+	style().drawItem(&p, r, AlignCenter, colorGroup(), true, pixmap,
+                         text, -1, &textColor);
 }
 
-void Field::drawCase(uint i, uint j)
+void Field::drawCase(QPainter &p, uint i, uint j)
 {
-	ASSERT( inside(i, j) );
+	Q_ASSERT( inside(i, j) );
 	switch (pfield(i, j).state) {
-	case Covered:   drawBox(i, j, false);
-		            break;
-	case Marked:    drawBox(i, j, false, &pm_flag);
-		            break;
-	case Error:     drawBox(i, j, true, &pm_error);
-		            break;
-	case Uncertain: drawBox(i, j, false, "?");
-					break;
-	case Exploded:  drawBox(i, j, true, &pm_exploded);
-					break;
-	case Uncovered: if ( pfield(i, j).mine )
-		                drawBox(i, j, true, &pm_mine);
-	                else {
-						uint n = computeNeighbours(i, j);
-						QString nb;
-						if (n) nb.setNum(n);
-						drawBox(i, j, true, nb,
-								n ? &cp.numberColors[n-1] : 0);
-					}
+		case Covered:
+			drawBox(p, i, j, false);
+			break;
+	case Marked:
+			drawBox(p, i, j, false, &pm_flag);
+			break;
+	case Error:
+			drawBox(p, i, j, true, &pm_error);
+			break;
+	case Uncertain:
+			drawBox(p, i, j, false, 0, "?", black);
+			break;
+	case Exploded:
+			drawBox(p, i, j, true, &pm_exploded);
+			break;
+	case Uncovered:
+        	if ( pfield(i, j).mine ) drawBox(p, i, j, true, &pm_mine);
+        	else {
+                uint n = computeNeighbours(i, j);
+                QString nb;
+                if (n) nb.setNum(n);
+                drawBox(p, i, j, true, 0, nb,
+                        n ? cp.numberColors[n-1] : black);
+        	}
 	}
 }
