@@ -3,11 +3,13 @@
 
 #include <qframe.h>
 #include <qstring.h>
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qpalette.h>
 
 #include "gamecore.h"
 
+class QLabel;
+
 struct planet_info_buffer {
     Planet *planet;
     int production;
@@ -15,8 +17,8 @@ struct planet_info_buffer {
     float killRate;
 };
 
-typedef QList<planet_info_buffer> PlanetInfoList;
-typedef QListIterator<planet_info_buffer> PlanetInfoListIterator;
+typedef QPtrList<planet_info_buffer> PlanetInfoList;
+typedef QPtrListIterator<planet_info_buffer> PlanetInfoListIterator;
 
 class PlanetInfo : public QFrame
 {
