@@ -1,9 +1,7 @@
 #include "clock.h"
 #include <klocale.h>
-#include <kdebug.h>
 #include "pile.h"
 #include "deck.h"
-#include <kmainwindow.h>
 #include <assert.h>
 
 Clock::Clock( KMainWindow* parent, const char *name )
