@@ -24,15 +24,11 @@
 
 #include "klondike.h"
 #include <klocale.h>
-#include <kmessagebox.h>
 #include <card.h>
-#include <kmainwindow.h>
 #include <deck.h>
 #include <pile.h>
 #include <kdebug.h>
 #include <assert.h>
-#include <kaction.h>
-#include <qtimer.h>
 
 Klondike::Klondike( bool easy, KMainWindow* parent, const char* _name )
   : Dealer( parent, _name )
@@ -189,7 +185,7 @@ void Klondike::deal3()
         // move back to flip
         item->move(deck->x(), deck->y());
 
-        item->flipTo( pile->x(), pile->y(), 8 * (flipped + 1) );
+        item->flipTo( int(pile->x()), int(pile->y()), 8 * (flipped + 1) );
     }
 
 }
