@@ -16,7 +16,7 @@
 
  */
 
-#include <kapp.h>
+#include <kapplication.h>
 #include <klocale.h>
 #include <kcmdlineargs.h>
 #include <kaboutdata.h>
