@@ -1,4 +1,4 @@
-#include <qlist.h>
+#include <qptrlist.h>
 
 #include "internal.h"
 
@@ -12,10 +12,11 @@
 #define BROKE_ERROR(i) { brokeError(i); return; }
 #define LAG_ERROR      { lagError();    return; }
 
-// Local implementation
+
+//-----------------------------------------------------------------------------
 void Local::dataError(uint i)
 {
-	qWarning("Invalid data from board #%i", i);
+	qWarning("MP : Invalid data from board #%i", i);
 }
 
 void Local::readData(bool inverse)
@@ -45,9 +46,9 @@ void Local::treatData()
 	for (uint i=0; i<ios.size(); i++)
 		if ( !ios[i]->reading.readOk() ) DATA_ERROR(i);
 	writeData(TRUE);
-}	
+}
 
-// Server implementation
+//-----------------------------------------------------------------------------
 Server::Server(uint _interval)
 : interval(_interval)
 {
@@ -65,21 +66,21 @@ void Server::serverTimeout()
 	timeout();
 }
 
-// Network implementation
+//-----------------------------------------------------------------------------
 Network::Network(MPInterface *_interface,
 				 QValueList<MPInterface::Data> &_boards,
-				 const QList<RemoteHostData> &rhd)
+				 const QPtrList<RemoteHostData> &rhd)
 : Local(_interface, _boards)
 {
 	RemoteData rd;
-	QListIterator<RemoteHostData> it(rhd);
+	QPtrListIterator<RemoteHostData> it(rhd);
 	for (; it.current(); ++it) {
-		rd.socket = new Socket(it.current()->socket, TRUE, this);
+        rd.socket = it.current()->socket;
 		rd.socket->notifier()->setEnabled(TRUE);
 		connect(rd.socket->notifier(), SIGNAL(activated(int)),
-				SLOT(notifier(int)));
+                SLOT(notifier(int)));
 		uint nb = it.current()->bds.count();
-		ASSERT( nb>=1 );
+		Q_ASSERT( nb>=1 );
 		rd.array  = new BufferArray(nb);
 		for (uint k=0; k<it.current()->bds.count(); k++)
 			rd.names += it.current()->bds[k].name;
@@ -122,7 +123,7 @@ IOBuffer *Network::ioBuffer(uint i) const
 		if ( i<remotes[k].array->size() ) return (*remotes[k].array)[i];
 		i -= remotes[k].array->size();
 	}
-	ASSERT(FALSE);
+	Q_ASSERT(FALSE);
 	return 0;
 }
 
@@ -149,7 +150,7 @@ void Network::disconnectHost(uint i, const QString &msg)
 	interface->hostDisconnected(i, msg);
 }
 
-// LocalServer implementation
+//-----------------------------------------------------------------------------
 LocalServer::LocalServer(MPInterface *_interface,
 						 QValueList<MPInterface::Data> &_boards,
 						 uint _interval)
@@ -160,10 +161,10 @@ LocalServer::LocalServer(MPInterface *_interface,
 	serverTimeout();
 }
 
-// NetworkServer implementation
+//-----------------------------------------------------------------------------
 NetworkServer::NetworkServer(MPInterface *_interface,
 							 QValueList<MPInterface::Data> &_boards,
-							 const QList<RemoteHostData> &rhd, uint _interval)
+							 const QPtrList<RemoteHostData> &rhd, uint _interval)
 : Network(_interface, _boards, rhd), Server(_interval),
   nbReceived(remotes.count())
 {
@@ -172,7 +173,8 @@ NetworkServer::NetworkServer(MPInterface *_interface,
 	// to catch unexpected data
 	for (uint i=0; i<remotes.count(); i++) remotes[i].received = TRUE;
 	nbReceived = remotes.count();
-	serverTimeout();
+//  let the client the time to create itself ...
+//	serverTimeout();
 }
 
 void NetworkServer::timeout()
@@ -180,7 +182,6 @@ void NetworkServer::timeout()
 	if ( nbReceived<remotes.count() ) LAG_ERROR;
 	nbReceived = 0;
 	for (uint i=0; i<remotes.count(); i++) remotes[i].received = FALSE;
-	
 	// send MF_ASK : asking for data from clients
 	for (uint i=0; i<remotes.count(); i++) {
 		remotes[i].socket->writingStream() << MF_Ask;
@@ -194,14 +195,14 @@ void NetworkServer::notifier(int fd)
 	uint i;
 	for (i=0; i<remotes.count(); i++)
 		if ( remotes[i].socket->fd()==fd ) break;
-	ASSERT( i<remotes.count() );
-	
+	Q_ASSERT( i<remotes.count() );
+
 	if ( remotes[i].received ) READ_ERROR(i);
 	switch ( remotes[i].socket->read() ) {
 	 case -1: READ_ERROR(i);
 	 case  0: BROKE_ERROR(i);
 	}
-		
+
 	remotes[i].received = TRUE;
 	nbReceived++;
 
@@ -235,10 +236,11 @@ void NetworkServer::writeData(bool inverse)
 void NetworkServer::lagError()
 {
 	for (uint i=0; i<remotes.count(); i++)
-		if ( !remotes[i].received )	disconnectHost(i, i18n("client has not answered in time"));
+		if ( !remotes[i].received )
+            disconnectHost(i, i18n("client has not answered in time"));
 }
 
-// Client implementation
+//-----------------------------------------------------------------------------
 void Client::notifier(int)
 {
 	switch ( remotes[0].socket->read() ) {
@@ -275,3 +277,4 @@ void Client::notifier(int)
 	}
 	if ( !s.atEnd() ) qWarning("CLIENT : remaining data");
 }
+#include "internal.moc"
