@@ -3,18 +3,18 @@
 
 #include <kmenubar.h>
 #include <qpopupmenu.h>
-#include <qlcdnumber.h>
 
-#include <qlist.h>
+#include <qptrlist.h>
 #include <qfileinfo.h>
 
 #include <kmainwindow.h>
 
-#include "rattler.h"
-#include "trys.h"
-#include "score.h"
-#include "progress.h"
-#include "levels.h"
+class Rattler;
+class QLCDNumber;
+class Trys;
+class Score;
+class Progress;
+class Levels;
 
 class KAction;
 class KSelectAction;
