@@ -12,8 +12,8 @@ int Ai::calcShotDirections[DNUM]={4,7,10,12};
 int Ai::calcCollisions[DNUM]={30,15,10,10};
 int Ai::calcNextShot[DNUM]={300,200,90,60};
 
-Ai::Ai(int pn,ShipSprite* s[2],QList<BulletSprite>* b[2],
-       QList<MineSprite>* m[2],SConfig *c,SOptions *o)
+Ai::Ai(int pn,ShipSprite* s[2],QPtrList<BulletSprite>* b[2],
+       QPtrList<MineSprite>* m[2],SConfig *c,SOptions *o)
 {
    int i;
 
@@ -27,9 +27,9 @@ Ai::Ai(int pn,ShipSprite* s[2],QList<BulletSprite>* b[2],
       ship[i]=s[i];
       bullets[i]=b[i];
       mines[i]=m[i];
-      shipsNextPositions[i]=new QArray<AiSprite>
+      shipsNextPositions[i]=new QMemArray<AiSprite>
          ((int)(calcPositionNumber[opt->aiDifficulty[playerNumber]]/cfg->gamespeed));
-      aiMines[i]=new QArray<AiSprite>(cfg->maxMines);
+      aiMines[i]=new QMemArray<AiSprite>(cfg->maxMines);
       mineNumber[i]=0;
    }
    myShots.setAutoDelete(true);
@@ -161,7 +161,7 @@ AiSprite Ai::nextPosition(AiSprite sp,double mult)
    return sp; 
 }
 
-void Ai::nextPositions(AiSprite sp,QArray<AiSprite> *a,int frames)
+void Ai::nextPositions(AiSprite sp,QMemArray<AiSprite> *a,int frames)
 {
    int i,num;
    double fmult=cfg->gamespeed*frames;
