@@ -29,8 +29,10 @@ public slots:
    void energy(int pn,int en);
    void hitPoints(int pn,int hp);
    void wins(int pn,int w);
+private slots:
+   void slotStatusText(const QString &str, int id);
 signals:   
-   void setStatusText(const char* str,int id);
+   void setStatusText(const QString & str,int id);
 private:
    MyMainView *playfield;
    PlayerInfo *playerinfo[2];
